@@ -19,13 +19,15 @@ import re
 from typing import Dict, Sequence, Tuple, Type, Union
 import pkg_resources
 
-import google.api_core.client_options as ClientOptions  # type: ignore
+from google.api_core.client_options import ClientOptions  # type: ignore
 from google.api_core import exceptions as core_exceptions  # type: ignore
 from google.api_core import gapic_v1  # type: ignore
 from google.api_core import retry as retries  # type: ignore
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
+OptionalRetry = Union[retries.Retry, object]
+
 from google.api_core import operation  # type: ignore
 from google.api_core import operation_async  # type: ignore
 from google.cloud.orchestration.airflow.service_v1.services.environments import pagers
@@ -165,18 +167,18 @@ class EnvironmentsAsyncClient:
 
     async def create_environment(
         self,
-        request: environments.CreateEnvironmentRequest = None,
+        request: Union[environments.CreateEnvironmentRequest, dict] = None,
         *,
         parent: str = None,
         environment: environments.Environment = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
         r"""Create a new environment.
 
         Args:
-            request (:class:`google.cloud.orchestration.airflow.service_v1.types.CreateEnvironmentRequest`):
+            request (Union[google.cloud.orchestration.airflow.service_v1.types.CreateEnvironmentRequest, dict]):
                 The request object. Create a new environment.
             parent (:class:`str`):
                 The parent must be of the form
@@ -254,17 +256,17 @@ class EnvironmentsAsyncClient:
 
     async def get_environment(
         self,
-        request: environments.GetEnvironmentRequest = None,
+        request: Union[environments.GetEnvironmentRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> environments.Environment:
         r"""Get an existing environment.
 
         Args:
-            request (:class:`google.cloud.orchestration.airflow.service_v1.types.GetEnvironmentRequest`):
+            request (Union[google.cloud.orchestration.airflow.service_v1.types.GetEnvironmentRequest, dict]):
                 The request object. Get an environment.
             name (:class:`str`):
                 The resource name of the environment
@@ -325,17 +327,17 @@ class EnvironmentsAsyncClient:
 
     async def list_environments(
         self,
-        request: environments.ListEnvironmentsRequest = None,
+        request: Union[environments.ListEnvironmentsRequest, dict] = None,
         *,
         parent: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListEnvironmentsAsyncPager:
         r"""List environments.
 
         Args:
-            request (:class:`google.cloud.orchestration.airflow.service_v1.types.ListEnvironmentsRequest`):
+            request (Union[google.cloud.orchestration.airflow.service_v1.types.ListEnvironmentsRequest, dict]):
                 The request object. List environments in a project and
                 location.
             parent (:class:`str`):
@@ -406,19 +408,19 @@ class EnvironmentsAsyncClient:
 
     async def update_environment(
         self,
-        request: environments.UpdateEnvironmentRequest = None,
+        request: Union[environments.UpdateEnvironmentRequest, dict] = None,
         *,
         name: str = None,
         environment: environments.Environment = None,
         update_mask: field_mask_pb2.FieldMask = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
         r"""Update an environment.
 
         Args:
-            request (:class:`google.cloud.orchestration.airflow.service_v1.types.UpdateEnvironmentRequest`):
+            request (Union[google.cloud.orchestration.airflow.service_v1.types.UpdateEnvironmentRequest, dict]):
                 The request object. Update an environment.
             name (:class:`str`):
                 The relative resource name of the
@@ -669,17 +671,17 @@ class EnvironmentsAsyncClient:
 
     async def delete_environment(
         self,
-        request: environments.DeleteEnvironmentRequest = None,
+        request: Union[environments.DeleteEnvironmentRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
         r"""Delete an environment.
 
         Args:
-            request (:class:`google.cloud.orchestration.airflow.service_v1.types.DeleteEnvironmentRequest`):
+            request (Union[google.cloud.orchestration.airflow.service_v1.types.DeleteEnvironmentRequest, dict]):
                 The request object. Delete an environment.
             name (:class:`str`):
                 The environment to delete, in the
