@@ -19,13 +19,15 @@ import re
 from typing import Dict, Sequence, Tuple, Type, Union
 import pkg_resources
 
-import google.api_core.client_options as ClientOptions  # type: ignore
+from google.api_core.client_options import ClientOptions  # type: ignore
 from google.api_core import exceptions as core_exceptions  # type: ignore
 from google.api_core import gapic_v1  # type: ignore
 from google.api_core import retry as retries  # type: ignore
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
+OptionalRetry = Union[retries.Retry, object]
+
 from google.cloud.orchestration.airflow.service_v1beta1.services.image_versions import (
     pagers,
 )
@@ -163,17 +165,17 @@ class ImageVersionsAsyncClient:
 
     async def list_image_versions(
         self,
-        request: image_versions.ListImageVersionsRequest = None,
+        request: Union[image_versions.ListImageVersionsRequest, dict] = None,
         *,
         parent: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListImageVersionsAsyncPager:
         r"""List ImageVersions for provided location.
 
         Args:
-            request (:class:`google.cloud.orchestration.airflow.service_v1beta1.types.ListImageVersionsRequest`):
+            request (Union[google.cloud.orchestration.airflow.service_v1beta1.types.ListImageVersionsRequest, dict]):
                 The request object. List ImageVersions in a project and
                 location.
             parent (:class:`str`):
